@@ -14,7 +14,7 @@ except:
 def init_dataframe(args, input_file, sub_type):
 	check_na = -9999
 
-	df = common.load_dataframe(sub_type, input_file, 0)
+	df, columns = common.load_dataframe(sub_type, input_file, 0)
 	df.index.name = 'time'
 	df.replace(check_na, np.nan, inplace=True)
 
@@ -133,7 +133,7 @@ def imau2nc(args, input_file, output_file, stations):
 
 	comp_level = args.dfl_lvl
 	
-	common.load_dataset_attributes(sub_type, ds)
+	common.load_dataset_attributes(sub_type, ds, args)
 	encoding = common.get_encoding(sub_type, common.get_fillvalue(args), comp_level)
 
 	common.write_data(args, ds, output_file, encoding)
